@@ -61,7 +61,7 @@ int main(int argc, char **argv)
 {
 	char str_src_ip[STR_IP_LEN], str_dst_ip[STR_IP_LEN];
 	char errbuf[(LIBNET_ERRBUF_SIZE<PCAP_ERRBUF_SIZE) ? PCAP_ERRBUF_SIZE : LIBNET_ERRBUF_SIZE];
-	char *eth, *ptr, *ptr1, *ptr2;
+	char *eth=NULL, *ptr, *ptr1, *ptr2;
 	const u_char *packet;
 	int npid, scan_speed=0, cmd_parse, i, j, k, gotcha[2], known, read_ok=1, i_ip=0, timeout=0, verbose=0;
 	struct pcap_pkthdr phdr;
@@ -84,7 +84,7 @@ int main(int argc, char **argv)
 
 	// take a look to the arguments:
 	if(argc<3) usage(argv[0]);
-	while((cmd_parse=getopt(argc, argv, "s:d:p:k:t:r:e:v"))!=EOF)
+	while((cmd_parse=getopt(argc, argv, "s:d:p:k:t:r:e:vi:"))!=EOF)
 	{
 		switch(cmd_parse)
 		{
@@ -177,6 +177,9 @@ int main(int argc, char **argv)
 			case 'v':
 				verbose++;
 				break;
+			case 'i':
+				eth=optarg;
+				break;
 			case '?':
 			default:
 				usage(argv[0]);
@@ -218,8 +221,8 @@ int main(int argc, char **argv)
 		if(!(tab_fwrd=(fwrd_elt *)malloc(nb_src_ip*nbports*sizeof(fwrd_elt)))) error(NULL, -2);
 
 
-	// get an ethernet device name
-	if(!(eth=pcap_lookupdev(errbuf))) error(errbuf, -1);
+	// get an ethernet device name, if none is specified
+	if(!eth) if(!(eth=pcap_lookupdev(errbuf))) error(errbuf, -1);
 	fprintf(stdout, "Network device: %s\n", eth);
 
 
@@ -240,7 +243,7 @@ int main(int argc, char **argv)
 
 	// open a raw link interface to send spoofed ARP replies if needed (something like ARP poisoning)
 	if(!(interface=libnet_open_link_interface(eth, errbuf)))
-		libnet_error(LIBNET_ERR_FATAL, "libnet_open_link_interface failed (need to be root ?)\n");
+		libnet_error(LIBNET_ERR_FATAL, "libnet_open_link_interface failed (possible cause: need to be root, or invalid interface: %s)\n", eth);
 
 	// open network device in promiscuous mode
 	if(!(descr=pcap_open_live(eth, 0x10000, 1, -1, errbuf))) error(errbuf, -1);
@@ -857,8 +860,9 @@ void packet_generator(int scan_speed)
 
 void usage(char *cmd)
 {
-fprintf(stderr, "Usage: %s -s src_ip[,src_ip_1[,src_ip_2-4..]] -d dst_ip [-t scan_type] [-v]
+fprintf(stderr, "Usage: %s -s src_ip[,src_ip_1[,src_ip_2-4..]] -d dst_ip [-t scan_type] [-v]\n\
 	   [-r scan_speed] [-p first_port-last_port] [-k 0 | 1] [-e ping_port]\n\
+	   [-i interface]\n\
  -s src_ip[,src_ip_1..]: list of IP addresses of the hosts we pretend to be\n\
  -d dst_ip.............: target host's IP\n\
  -t scan_type..........: stealth scan mode (default: syn)\n\
@@ -868,7 +872,8 @@ fprintf(stderr, "Usage: %s -s src_ip[,src_ip_1[,src_ip_2-4..]] -d dst_ip [-t sca
  -p first-last ports...: ports range to scan (default: 1-1024)\n\
  -k 0 | 1..............: scan well-known ports (default: 1)\n\
  -e ping_port..........: target port for a TCP ping (default: 80)\n\
- -v....................: verbose (use twice for more verbose)\n", cmd);
+ -v....................: verbose (use twice for more verbose)\n\
+ -i interface..........: ethernet interface to use\n", cmd);
 exit(-1);
 }
 
